@@ -115,7 +115,9 @@ pub mod setup {
     /// instead.
     pub use super::io::chewing_Configure;
 
-    /// Resets all settings in the given Chewing IM instance.
+    /// Reset the context but keep all settings.
+    ///
+    /// All preedit buffers are reset to empty.
     ///
     /// The return value is 0 on success and -1 on failure.
     pub use super::io::chewing_Reset;
@@ -318,6 +320,7 @@ pub mod layout {
     /// * KB_THL_PINYIN
     /// * KB_MPS2_PINYIN
     /// * KB_CARPALX
+    /// * KB_COLEMAK
     /// * KB_COLEMAK_DH_ANSI
     /// * KB_COLEMAK_DH_ORTH
     /// * KB_WORKMAN
@@ -705,6 +708,17 @@ pub mod output {
     /// </p>
     pub use super::io::chewing_zuin_Check;
 
+    /// Returns the phonetic characters in the pre-edit buffer.
+    ///
+    /// The returned value is a pointer to a character string. The memory must
+    /// be freed by the caller using function
+    /// [chewing_free][super::setup::chewing_free].
+    ///
+    /// # Failures
+    ///
+    /// This function returns NULL when memory allocation fails.
+    pub use super::io::chewing_bopomofo_String;
+
     /// Returns the phonetic characters in the pre-edit buffer.
     ///
     /// The return value is a const pointer to a character string. The pointer
