@@ -125,11 +125,11 @@ pub(crate) fn try_load_bin<R: Read>(mut input: R) -> io::Result<Vec<(Vec<Syllabl
 
 #[cfg(test)]
 mod tests {
-    use std::{ffi::c_int, iter, mem::size_of};
+    use std::{ffi::c_int, mem::size_of};
 
     use crate::zhuyin::Syllable;
 
-    use super::{try_load_bin, try_load_text, Phrase, BIN_FIELD_SIZE};
+    use super::{BIN_FIELD_SIZE, Phrase, try_load_bin, try_load_text};
 
     #[test]
     fn load_valid_text() {
@@ -177,7 +177,10 @@ mod tests {
         input.extend_from_slice(&1_u16.to_ne_bytes());
         input.push(1);
         input.extend_from_slice(b"P");
-        input.extend(iter::repeat(0).take(BIN_FIELD_SIZE - input.len() + 4 + size_of::<c_int>()));
+        input.extend(std::iter::repeat_n(
+            0,
+            BIN_FIELD_SIZE - input.len() + 4 + size_of::<c_int>(),
+        ));
         let phrases = try_load_bin(&input[..]).unwrap();
         assert_eq!(
             vec![(
