@@ -20,14 +20,12 @@
 #include "chewing.h"
 #include "testhelper.h"
 
-FILE *fd;
-
 void test_set_null_logger()
 {
     ChewingContext *ctx;
 
     ctx = chewing_new();
-    start_testcase(ctx, fd);
+    start_testcase(ctx);
 
     chewing_set_logger(ctx, NULL, 0);
     type_keystroke_by_string(ctx, "hk4g4");
@@ -35,25 +33,34 @@ void test_set_null_logger()
     chewing_delete(ctx);
 }
 
+void stdout_logger(void *data, int level, const char *fmt, ...)
+{
+    va_list ap;
+    va_start(ap, fmt);
+    vprintf(fmt, ap);
+    va_end(ap);
+}
+
+void test_set_logger()
+{
+    ChewingContext *ctx;
+
+    ctx = chewing_new();
+    start_testcase(ctx);
+
+    chewing_set_logger(ctx, stdout_logger, 0);
+    type_keystroke_by_string(ctx, "hk4g4");
+
+    chewing_delete(ctx);
+}
+
 int main(int argc, char *argv[])
 {
-    char *logname;
-    int ret;
-
     putenv("CHEWING_PATH=" CHEWING_DATA_PREFIX);
     putenv("CHEWING_USER_PATH=" TEST_HASH_DIR);
 
-    ret = asprintf(&logname, "%s.log", argv[0]);
-    if (ret == -1)
-        return -1;
-    fd = fopen(logname, "w");
-    assert(fd);
-    free(logname);
-
-
+    test_set_logger();
     test_set_null_logger();
 
-    fclose(fd);
-
     return exit_status();
 }
