@@ -16,8 +16,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "plat_types.h"
-
 int ueStrLen(const char *str);
 
 static unsigned int test_run;
@@ -99,7 +97,7 @@ BufferType BOPOMOFO_BUFFER = {
     chewing_bopomofo_Check,
     chewing_zuin_Check,
     0,
-    0,
+    chewing_bopomofo_String,
     chewing_zuin_String,
     chewing_bopomofo_String_static
 };
@@ -395,23 +393,11 @@ void internal_ok_keystroke_rtn(const char *file, int line, ChewingContext *ctx,
     }
 }
 
-void logger(void *data, int _level, const char *fmt, ...)
-{
-    va_list ap;
-    FILE *fd = (FILE *) data;
-
-    va_start(ap, fmt);
-    vfprintf(fd, fmt, ap);
-    va_end(ap);
-}
-
-void internal_start_testcase(const char *func, ChewingContext *ctx, FILE * file)
+void internal_start_testcase(const char *func, ChewingContext *ctx)
 {
     assert(func);
 
     printf("#\n# %s\n#\n", func);
-    fprintf(file, "#\n# %s\n#\n", func);
-    chewing_set_logger(ctx, logger, file);
 }
 
 int exit_status()
@@ -426,7 +412,7 @@ char *get_test_userphrase_path()
     if (userphrase_path)
         return userphrase_path;
     else
-        return TEST_HASH_DIR PLAT_SEPARATOR DB_NAME;
+        return TEST_HASH_DIR "/" DB_NAME;
 }
 
 void clean_userphrase()
